@@ -15,7 +15,18 @@
 #include <asm/io.h>
 #include <asm/irq.h>
 #include <asm/uaccess.h>
+#include <linux/version.h>
+#include <linux/mutex.h>
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,23) 
 #include <linux/freezer.h>
+#else
+#define set_freezable()
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,11) 
+typedef struct pm_message {
+        int event;
+} pm_message_t;
+#endif
+#endif
 #include <linux/kthread.h>
 #include <linux/dma-mapping.h>
 
@@ -58,10 +69,17 @@ MODULE_DEVICE_TABLE(pci, pt1_pci_tbl);
 #define		MAX_READ_BLOCK	4			// 1٤ɤ߽ФDMAХåե
 #define		MAX_PCI_DEVICE		64		// 64
 #define		DMA_SIZE	4096			// DMAХåե
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,22) 
 #define		DMA_RING_SIZE	64			// RING
 #define		DMA_RING_MAX	511			// 1RINGˤĵͤ뤫(1023NG511ޤ)
-#define		CHANEL_DMA_SIZE	(1*1024*1024)	// ϥǥ(16Mbps)
-#define		BS_CHANEL_DMA_SIZE	(1*1024*1024)	// BS(32Mbps)
+#define		CHANEL_DMA_SIZE	(2*1024*1024)	// ϥǥ(16Mbps)
+#define		BS_CHANEL_DMA_SIZE	(4*1024*1024)	// BS(32Mbps)
+#else
+#define		DMA_RING_SIZE	28			// RING
+#define		DMA_RING_MAX	511			// 1RINGˤĵͤ뤫(1023NG511ޤ)
+#define		CHANEL_DMA_SIZE	(1*128*1024)	// ϥǥ(16Mbps)
+#define		BS_CHANEL_DMA_SIZE	(1*128*1024)	// BS(32Mbps)
+#endif
 
 typedef	struct	_DMA_CONTROL{
 	dma_addr_t	ring_dma[DMA_RING_MAX] ;	// DMA
@@ -74,7 +92,7 @@ typedef	struct	_pt1_device{
 	unsigned long	mmio_start ;
 	__u32			mmio_len ;
 	void __iomem		*regs;
-	spinlock_t			lock ;
+	struct mutex		lock ;
 	dma_addr_t		ring_dma[DMA_RING_SIZE] ;	// DMA
 	void			*dmaptr[DMA_RING_SIZE] ;
 	struct	task_struct	*kthread;
@@ -97,7 +115,7 @@ struct	_PT1_CHANNEL{
 	__u32			channel ;		// ֹͥ
 	int				type ;			// ͥ륿
 	__u32			drop ;			// ѥåȥɥå׿
-	spinlock_t		lock ;			// CHspin_lock
+	struct mutex		lock ;			// CHmutex_lock
 	__u32			size ;			// DMA줿
 	__u32			maxsize ;		// DMAѥХåե
 	__u32			bufsize ;		// ͥ˳꿶줿
@@ -118,6 +136,7 @@ int		channeltype[MAX_CHANNEL] = {CHANNEL_TYPE_ISDB_S, CHANNEL_TYPE_ISDB_S,
 									CHANNEL_TYPE_ISDB_T, CHANNEL_TYPE_ISDB_T};
 
 static	PT1_DEVICE	*device[MAX_PCI_DEVICE];
+static struct class	*pt1video_class;
 
 #define		PT1MAJOR	251
 #define		DRIVERNAME	"pt1video"
@@ -135,10 +154,7 @@ static	void	reset_dma(PT1_DEVICE *dev_conf)
 	for(ring_pos = 0 ; ring_pos < DMA_RING_SIZE ; ring_pos++){
 		for(data_pos = 0 ; data_pos < DMA_RING_MAX ; data_pos++){
 			dataptr = dev_conf->dmactl[ring_pos].data[data_pos];
-			// ǡꡩ
-			if(dataptr[(DMA_SIZE / sizeof(__u32)) - 2] == 0){
-				break ;
-			}
+			dataptr[(DMA_SIZE / sizeof(__u32)) - 2] = 0;
 		}
 	}
 	// ž󥿤ꥻå
@@ -217,18 +233,18 @@ static	int		pt1_thread(void *data)
 				if(channel->valid == FALSE){
 					continue ;
 				}
-				spin_lock(&channel->lock);
+				mutex_lock(&channel->lock);
 				// դ줿ɤ߽ФޤԤ
 				while(1){
 					if(channel->size >= (channel->maxsize - 4)){
 						// ͥDMAɤߤԤˤ
 						wake_up(&channel->wait_q);
 						channel->req_dma = TRUE ;
-						spin_unlock(&channel->lock);
+						mutex_unlock(&channel->lock);
 						// ˻֤Ϥ
 						wait_event_timeout(dev_conf->dma_wait_q, (channel->req_dma == FALSE),
 											msecs_to_jiffies(500));
-						spin_lock(&channel->lock);
+						mutex_lock(&channel->lock);
 						channel->drop += 1 ;
 					}else{
 						break ;
@@ -239,7 +255,7 @@ static	int		pt1_thread(void *data)
 					channel->buf[channel->size] = micro.packet.data[lp2];
 					channel->size += 1 ;
 				}
-				spin_unlock(&channel->lock);
+				mutex_unlock(&channel->lock);
 			}
 			curdataptr[(DMA_SIZE / sizeof(__u32)) - 2] = 0;
 
@@ -277,18 +293,14 @@ static int pt1_open(struct inode *inode, struct file *file)
 		if(device[lp] == NULL){
 			return -EIO ;
 		}
-		printk(KERN_INFO "(%d)base_minor=%d: MAX=%d(%d)\n",
-				lp, device[lp]->base_minor,
-				(device[lp]->base_minor + MAX_CHANNEL), minor);
 		if((device[lp]->base_minor <= minor) &&
 			((device[lp]->base_minor + MAX_CHANNEL) > minor)){
-			spin_lock(&device[lp]->lock);
+			mutex_lock(&device[lp]->lock);
 			for(lp2 = 0 ; lp2 < MAX_CHANNEL ; lp2++){
 				channel = device[lp]->channel[lp2] ;
-				printk(KERN_INFO "Minor(%d:%d)\n", channel->minor, minor);
 				if(channel->minor == minor){
 					if(channel->valid == TRUE){
-						spin_unlock(&device[lp]->lock);
+						mutex_unlock(&device[lp]->lock);
 						return -EIO ;
 					}
 					channel->drop  = 0 ;
@@ -297,11 +309,11 @@ static int pt1_open(struct inode *inode, struct file *file)
 					channel->counetererr = 0 ;
 					channel->transerr = 0 ;
 					file->private_data = channel;
-					spin_lock(&channel->lock);
+					mutex_lock(&channel->lock);
 					// ǡ
 					channel->size = 0 ;
-					spin_unlock(&channel->lock);
-					spin_unlock(&device[lp]->lock);
+					mutex_unlock(&channel->lock);
+					mutex_unlock(&device[lp]->lock);
 					return 0 ;
 				}
 			}
@@ -314,7 +326,7 @@ static int pt1_release(struct inode *inode, struct file *file)
 	int		minor = iminor(inode);
 	PT1_CHANNEL	*channel = file->private_data;
 
-	spin_lock(&channel->ptr->lock);
+	mutex_lock(&channel->ptr->lock);
 	SetStream(channel->ptr->regs, channel->channel, FALSE);
 	channel->valid = FALSE ;
 	printk(KERN_INFO "(%d)Drop=%08d:%08d:%08d:%08d\n", iminor(inode), channel->drop,
@@ -328,7 +340,7 @@ static int pt1_release(struct inode *inode, struct file *file)
 		channel->req_dma = FALSE ;
 		wake_up(&channel->ptr->dma_wait_q);
 	}
-	spin_unlock(&channel->ptr->lock);
+	mutex_unlock(&channel->ptr->lock);
 	return 0;
 }
 
@@ -343,7 +355,7 @@ static ssize_t pt1_read(struct file *file, char __user *buf, size_t cnt, loff_t
 		wait_event_timeout(channel->wait_q, (channel->size >= DMA_SIZE),
 							msecs_to_jiffies(500));
 	}
-	spin_lock(&channel->lock);
+	mutex_lock(&channel->lock);
 	if(!channel->size){
 		size = 0 ;
 	}else{
@@ -360,11 +372,11 @@ static ssize_t pt1_read(struct file *file, char __user *buf, size_t cnt, loff_t
 		}
 	}
 	// ɤ߽äĻѤƤΤ4Kʲ
-	if((channel->req_dma == TRUE) && (channel->size < DMA_SIZE)){
+	if(channel->req_dma == TRUE){
 		channel->req_dma = FALSE ;
 		wake_up(&channel->ptr->dma_wait_q);
 	}
-	spin_unlock(&channel->lock);
+	mutex_unlock(&channel->lock);
 	return size ;
 }
 static	int		SetFreq(PT1_CHANNEL *channel, FREQUENCY *freq)
@@ -374,18 +386,13 @@ static	int		SetFreq(PT1_CHANNEL *channel, FREQUENCY *freq)
 		case CHANNEL_TYPE_ISDB_S:
 			{
 				ISDB_S_TMCC		tmcc ;
-				int				lp ;
-
 				if(bs_tune(channel->ptr->regs,
-						channel->ptr->lock,
+						&channel->ptr->lock,
 						channel->address,
 						freq->frequencyno,
 						&tmcc) < 0){
 					return -EIO ;
 				}
-				printk(KERN_INFO "cn = (%x:%x)\n", (tmcc.cn[0] & 0xFF),
-						(tmcc.cn[1] & 0xFF));
-				printk(KERN_INFO "agc = (%x)\n", (tmcc.agc & 0xFF));
 
 #if 0
 				printk(KERN_INFO "clockmargin = (%x)\n", (tmcc.clockmargin & 0xFF));
@@ -404,7 +411,7 @@ static	int		SetFreq(PT1_CHANNEL *channel, FREQUENCY *freq)
 				}
 #endif
 				ts_lock(channel->ptr->regs,
-						channel->ptr->lock,
+						&channel->ptr->lock,
 						channel->address,
 						tmcc.ts_id[freq->slot].ts_id);
 			}
@@ -412,7 +419,7 @@ static	int		SetFreq(PT1_CHANNEL *channel, FREQUENCY *freq)
 		case CHANNEL_TYPE_ISDB_T:
 			{
 				if(isdb_t_frequency(channel->ptr->regs,
-						channel->ptr->lock,
+						&channel->ptr->lock,
 						channel->address,
 						freq->frequencyno, freq->slot) < 0){
 					return -EINVAL ;
@@ -424,6 +431,7 @@ static	int		SetFreq(PT1_CHANNEL *channel, FREQUENCY *freq)
 static	int	pt1_ioctl(struct inode *inode, struct file  *file, unsigned int cmd, void *arg)
 {
 	PT1_CHANNEL	*channel = file->private_data;
+	int			signal ;
 
 	switch(cmd){
 		case SET_CHANNEL:
@@ -438,6 +446,33 @@ static	int	pt1_ioctl(struct inode *inode, struct file  *file, unsigned int cmd,
 		case STOP_REC:
 			SetStream(channel->ptr->regs, channel->channel, FALSE);
 			return 0 ;
+		case GET_SIGNAL_STRENGTH:
+			switch(channel->type){
+				case CHANNEL_TYPE_ISDB_S:
+					{
+						signal = isdb_s_read_signal_strength(channel->ptr->regs,
+													&channel->ptr->lock,
+													channel->address);
+					}
+					break ;
+				case CHANNEL_TYPE_ISDB_T:
+                	// calc C/N
+					signal = isdb_t_read_signal_strength(channel->ptr->regs, 
+												&channel->ptr->lock, channel->address);
+					break ;
+			}
+			copy_to_user(arg, &signal, sizeof(int));
+			return 0 ;
+		case LNB_ENABLE:
+			if(lnb){
+				settuner_reset(channel->ptr->regs, lnb, TUNER_POWER_ON_RESET_DISABLE);
+			}
+			return 0 ;
+		case LNB_DISABLE:
+			if(lnb){
+				settuner_reset(channel->ptr->regs, LNB_OFF, TUNER_POWER_ON_RESET_DISABLE);
+			}
+			return 0 ;
 	}
 	return -EINVAL;
 }
@@ -588,14 +623,13 @@ static int __devinit pt1_pci_init_one (struct pci_dev *pdev,
 	settuner_reset(dev_conf->regs, LNB_OFF, TUNER_POWER_ON_RESET_ENABLE);
 	schedule_timeout_interruptible(msecs_to_jiffies(50));
 
-	settuner_reset(dev_conf->regs, lnb, TUNER_POWER_ON_RESET_DISABLE);
+	settuner_reset(dev_conf->regs, LNB_OFF, TUNER_POWER_ON_RESET_DISABLE);
 	schedule_timeout_interruptible(msecs_to_jiffies(10));
-	spin_lock_init(&dev_conf->lock);
-	spin_lock_init(&dev_conf->lock);
+	mutex_init(&dev_conf->lock);
 
 	// Tuner 
 	for(lp = 0 ; lp < MAX_TUNER ; lp++){
-		rc = tuner_init(dev_conf->regs, dev_conf->lock, lp);
+		rc = tuner_init(dev_conf->regs, &dev_conf->lock, lp);
 		if(rc < 0){
 			printk(KERN_ERR "Error tuner_init\n");
 			goto out_err_fpga;
@@ -603,7 +637,7 @@ static int __devinit pt1_pci_init_one (struct pci_dev *pdev,
 	}
 	// λ
 	for(lp = 0 ; lp < MAX_CHANNEL ; lp++){
-		set_sleepmode(dev_conf->regs, dev_conf->lock, 
+		set_sleepmode(dev_conf->regs, &dev_conf->lock, 
 						i2c_address[lp], channeltype[lp], TYPE_SLEEP);
 		
 		schedule_timeout_interruptible(msecs_to_jiffies(50));
@@ -621,7 +655,6 @@ static int __devinit pt1_pci_init_one (struct pci_dev *pdev,
 	for(lp = 0 ; lp < MAX_PCI_DEVICE ; lp++){
 		if(device[lp] == NULL){
 			device[lp] = dev_conf ;
-			printk(KERN_INFO "Alloc[%d]\n", lp);
 			break ;
 		}
 	}
@@ -635,12 +668,11 @@ static int __devinit pt1_pci_init_one (struct pci_dev *pdev,
 		}
 
 		// ̾
-		spin_lock_init(&channel->lock);
+		mutex_init(&channel->lock);
 		// Ԥ֤
 		channel->req_dma = FALSE ;
 		// ޥʡֹ
 		channel->minor = MINOR(dev_conf->dev) + lp ;
-		printk(KERN_INFO "Minor[%d]\n", channel->minor);
 		// оݤI2CǥХ
 		channel->address = i2c_address[lp] ;
 		channel->type = channeltype[lp] ;
@@ -665,6 +697,16 @@ static int __devinit pt1_pci_init_one (struct pci_dev *pdev,
 		if(channel->buf == NULL){
 			goto out_err_v4l;
 		}
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,27)
+		device_create(pt1video_class, NULL, MKDEV(MAJOR(dev_conf->dev),
+						(MINOR(dev_conf->dev) + lp)), NULL,
+						"pt1video%u", MINOR(dev_conf->dev) + lp);
+#else
+		device_create(pt1video_class, NULL, MKDEV(MAJOR(dev_conf->dev),
+						(MINOR(dev_conf->dev) + lp)),
+						"pt1video%u", MINOR(dev_conf->dev) + lp);
+#endif
+
 #if 0
 		dev_conf->vdev[lp] = video_device_alloc();
 		memcpy(dev_conf->vdev[lp], &pt1_template, sizeof(pt1_template));
@@ -730,6 +772,8 @@ static void __devexit pt1_pci_remove_one(struct pci_dev *pdev)
 				kfree(dev_conf->channel[lp]->buf);
 				kfree(dev_conf->channel[lp]);
 			}
+			device_destroy(pt1video_class, 
+							MKDEV(MAJOR(dev_conf->dev), (MINOR(dev_conf->dev) + lp)));
 		}
 		unregister_chrdev_region(dev_conf->dev, MAX_CHANNEL);
 		writel(0xb0b0000, dev_conf->regs);
@@ -771,12 +815,16 @@ static struct pci_driver pt1_driver = {
 
 static int __init pt1_pci_init(void)
 {
+	pt1video_class = class_create(THIS_MODULE, DRIVERNAME);
+	if (IS_ERR(pt1video_class))
+		return PTR_ERR(pt1video_class);
 	return pci_register_driver(&pt1_driver);
 }
 
 
 static void __exit pt1_pci_cleanup(void)
 {
+	class_destroy(pt1video_class);
 	pci_unregister_driver (&pt1_driver);
 }
 
