@@ -6,6 +6,7 @@
 #include <linux/pci.h>
 #include <linux/init.h>
 #include <linux/interrupt.h>
+#include <linux/mutex.h>
 
 #include <asm/system.h>
 #include <asm/io.h>
@@ -17,17 +18,7 @@
 #include	"pt1_i2c.h"
 #include	"pt1_tuner.h"
 #include	"pt1_tuner_data.h"
-/*
-  LNB  : BIT 2 1
-   OFF :     0 0
-   +15V:     1 1
-   +11V:     1 0
 
-  TUNER: BIT        3 0
-   POWER-OFF      : 0 0
-   POWER-ON RESET : 0 1
-   POWER-ON ONLY  : 1 1
-*/
 typedef	struct	_TUNER_INFO{
 	int		isdb_s ;
 	int		isdb_t ;
@@ -66,12 +57,12 @@ void	settuner_reset(void __iomem *regs, __u32 lnb, __u32 tuner)
 
 	switch(tuner){
 		case TUNER_POWER_ON_RESET_ENABLE: val |= (1 << BIT_TUNER) ; break ;
-		case TUNER_POWER_ON_RESET_DISABLE: val = (1 << BIT_TUNER) | (1 << BIT_RESET) ; break ;
+		case TUNER_POWER_ON_RESET_DISABLE: val |= (1 << BIT_TUNER) | (1 << BIT_RESET) ; break ;
 	}
 
 	writel(val, (regs + 4));
 }
-static	int		init_isdb_s(void __iomem *regs, spinlock_t lock, __u32 addr)
+static	int		init_isdb_s(void __iomem *regs, struct mutex *lock, __u32 addr)
 {
 
 	WBLOCK	wk;
@@ -97,7 +88,7 @@ static	int		init_isdb_s(void __iomem *regs, spinlock_t lock, __u32 addr)
 
 	return 0 ;
 }
-static	void	init_isdb_t(void __iomem *regs, spinlock_t lock, __u32 addr)
+static	void	init_isdb_t(void __iomem *regs, struct mutex *lock, __u32 addr)
 {
 	int		lp ;
 	WBLOCK	wk;
@@ -111,7 +102,7 @@ static	void	init_isdb_t(void __iomem *regs, spinlock_t lock, __u32 addr)
 
 
 }
-int		tuner_init(void __iomem *regs, spinlock_t lock, int tuner_no)
+int		tuner_init(void __iomem *regs, struct mutex *lock, int tuner_no)
 {
 
 	int		rc ;
@@ -142,7 +133,7 @@ int		tuner_init(void __iomem *regs, spinlock_t lock, int tuner_no)
 
 	return 0 ;
 }
-void	set_sleepmode(void __iomem *regs, spinlock_t lock, int address, int tuner_type, int type)
+void	set_sleepmode(void __iomem *regs, struct mutex *lock, int address, int tuner_type, int type)
 {
 	WBLOCK	wk;
 
@@ -174,7 +165,7 @@ void	set_sleepmode(void __iomem *regs, spinlock_t lock, int address, int tuner_t
 	i2c_write(regs, lock, &wk);
 }
 
-int		bs_frequency(void __iomem *regs, spinlock_t lock, int addr, int channel)
+int		bs_frequency(void __iomem *regs, struct mutex *lock, int addr, int channel)
 {
 	int		lp ;
 	int		tmcclock = FALSE ;
@@ -232,7 +223,7 @@ int		bs_frequency(void __iomem *regs, spinlock_t lock, int addr, int channel)
 
 	return 0 ;
 }
-int		ts_lock(void __iomem *regs, spinlock_t lock, int addr, __u16 ts_id)
+int		ts_lock(void __iomem *regs, struct mutex *lock, int addr, __u16 ts_id)
 {
 
 	int		lp ;
@@ -262,7 +253,7 @@ int		ts_lock(void __iomem *regs, spinlock_t lock, int addr, __u16 ts_id)
 	printk(KERN_INFO "PT1:ERROR TS-LOCK(%x)\n", ts_id);
 	return -EIO ;
 }
-int		bs_tune(void __iomem *regs, spinlock_t lock, int addr, int channel, ISDB_S_TMCC *tmcc)
+int		bs_tune(void __iomem *regs, struct mutex *lock, int addr, int channel, ISDB_S_TMCC *tmcc)
 {
 
 	int		lp ;
@@ -306,16 +297,8 @@ int		bs_tune(void __iomem *regs, spinlock_t lock, int addr, int channel, ISDB_S_
 		tsid += 1;
 	}
 
-	memcpy(&wk, &bs_get_cn, sizeof(WBLOCK));
-	wk.addr = addr;
-	tmcc->cn[0] = i2c_read(regs, lock, &wk, 1);
-
 	memcpy(&wk, &bs_get_agc, sizeof(WBLOCK));
 	wk.addr = addr;
-	tmcc->cn[1] = i2c_read(regs, lock, &wk, 1);
-
-	memcpy(&wk, &bs_get_maxagc, sizeof(WBLOCK));
-	wk.addr = addr;
 	tmcc->agc = i2c_read(regs, lock, &wk, 1);
 
 	// TS-ID̤ξ
@@ -346,6 +329,25 @@ int		bs_tune(void __iomem *regs, spinlock_t lock, int addr, int channel, ISDB_S_
 	tmcc->carriermargin = i2c_read(regs, lock, &wk, 1);
 	return 0 ;
 }
+int		isdb_s_read_signal_strength(void __iomem *regs, struct mutex *lock, int addr)
+{
+	WBLOCK	wk;
+	__u32	val ;
+	__u32	val2;
+	int		val3 ;
+
+	memcpy(&wk, &bs_get_signal1, sizeof(WBLOCK));
+	wk.addr = addr;
+	val = i2c_read(regs, lock, &wk, 1);
+
+	memcpy(&wk, &bs_get_signal2, sizeof(WBLOCK));
+	wk.addr = addr;
+	val2 = i2c_read(regs, lock, &wk, 1);
+	val3 = (((val << 8) & 0XFF00) | (val2 & 0XFF));
+
+	return val3 ;
+}
+
 __u32	getfrequency_add(__u32 channel)
 {
 	int		lp ;
@@ -377,7 +379,7 @@ __u32	getfrequency(__u32 channel, int addfreq)
 	return frequencyOffset + 400;
 
 }
-int		isdb_t_frequency(void __iomem *regs, spinlock_t lock, int addr, int channel, int addfreq)
+int		isdb_t_frequency(void __iomem *regs, struct mutex *lock, int addr, int channel, int addfreq)
 {
 
 	int		lp ;
@@ -445,8 +447,26 @@ int		isdb_t_frequency(void __iomem *regs, spinlock_t lock, int addr, int channel
 	}
 	return 0 ;
 }
+int		isdb_t_read_signal_strength(void __iomem *regs, struct mutex *lock, int addr)
+{
+	__u32	val ;
+	__u32	val2;
+	__u32	val3;
+	WBLOCK	wk;
+
+	memcpy(&wk, &isdb_t_signal1, sizeof(WBLOCK));
+	wk.addr = addr;
+	val = i2c_read(regs, lock, &wk, 1);
+	printk(KERN_INFO "CN(1)Val(%x)\n", val);
+
+	memcpy(&wk, &isdb_t_signal2, sizeof(WBLOCK));
+	wk.addr = addr;
+	val2 = i2c_read(regs, lock, &wk, 1);
+	val3 = (((val << 8) & 0XFF00) | (val2 & 0XFF));
+	return val3 ;
+}
 #if 0
-int		isdb_t_tune(void __iomem *regs, spinlock_t lock, int addr, int channel, ISDB_T_TMCC *tmcc)
+int		isdb_t_tune(void __iomem *regs, struct mutex *lock, int addr, int channel, ISDB_T_TMCC *tmcc)
 {
 
 	int		lp ;
