@@ -41,9 +41,9 @@ extern	WBLOCK	bs_set_ts_lock;
 extern	WBLOCK	bs_get_slot;
 extern	WBLOCK	bs_get_clock;
 extern	WBLOCK	bs_get_carrir;
-extern	WBLOCK	bs_get_cn;
+extern	WBLOCK	bs_get_signal1;
+extern	WBLOCK	bs_get_signal2;
 extern	WBLOCK	bs_get_agc;
-extern	WBLOCK	bs_get_maxagc;
 /***************************************************************************/
 /* ϥǥѥǡ                                                      */
 /***************************************************************************/
@@ -54,10 +54,9 @@ extern	WBLOCK	isdb_t_check_tune;
 extern	WBLOCK	isdb_t_tune_read;
 extern	WBLOCK	isdb_t_tmcc_read_1;
 extern	WBLOCK	isdb_t_tmcc_read_1;
-extern	WBLOCK	isdb_t_cn_1;
-extern	WBLOCK	isdb_t_cn_2;
-extern	WBLOCK	isdb_t_agc_1;
-extern	WBLOCK	isdb_t_agc_2;
+extern	WBLOCK	isdb_t_signal1;
+extern	WBLOCK	isdb_t_signal2;
+extern	WBLOCK	isdb_t_agc2;
 
 extern	WBLOCK	isdb_t_get_clock;
 extern	WBLOCK	isdb_t_get_carrir;
